<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;

class Question extends Model {

    public $table = 'questions';
    public $primaryKey = 'id';

    protected $fillable = [
    ];

}
